---
title: 카드사 심사
category: 포트원 이용절차 (온보딩 가이드) > 전자결제 신청 > 카드사 심사
seo:
  title: 카드사 심사
  description: >-
    포트원 전자결제 신청을 위한 안내입니다. 카드사 심사의 경우 PG사에서 모든 카드사로 심사를 요청합니다. 미리 준비하실 부분부터 카드사
    심사진행 현황조회까지 확인해보세요.
  keywords:
    - 카드사 심사
    - 전자결제신청
tags:
  - 공통
  - 카드사 심사
  - 전자결제신청
pgCompanies:
  - 공통
searchTags:
  - 소요일
  - 계약지연
  - 심사진행현황
  - 미리준비하기
  - 카드사심사
---

<Callout content="카드사 심사는 PG사에서 전 카드사로 심사를 요청합니다.
각 카드사별로 개별적으로 심사를 진행하기 때문에 소요 일시는 카드사별로 차이가 있을 수 있으나, 보통 2주 정도 소요됩니다. PG사를 통해 심사를 마치셨을지라도 기존과 다른 서비스를 운영하시거나 결제방식이 달라진다면 카드사 재심사가 필요합니다." />

### **미리 준비하기**

심사 받으실 사이트(앱) 내 결제연동된 화면을 준비합니다.  카드사 심사 전에는 테스트 환경으로 미리 연동 개발작업을 진행할 수 있습니다.

**결제창 방식**일 경우 결제대행사의 결제창이 정상적으로 뜨는지,  결제창 화면 내 카드사 목록이 모두 노출되는지 등을 확인하며, **API 방식**은 유저에게 카드정보를 받는 화면을 고객사에서 직접 구현하시므로 카드번호 + 유효기간 + 비밀번호 앞 2자리 + 생년월일(혹은 사업자번호) 를 입력할 수 있는 화면이 구현이 되어있는지 확인합니다.

아직 카드사 심사가 완료되지 않았기 때문에 운영 환경의 경우 결제가 실패되는 것이 당연하며 카드사 심사시 정상 결제여부나 이후 로직까지는 확인하지 않기 때문에 염려하지 않으셔도 됩니다.

자세한 사항은 이용하실 결제대행사별로 테스트환경 설정방법을 확인하여 주세요.

<Callout title="결제대행사별 결제 채널설정방법 보러가기↗" content="" />

### **카드사 심사진행 현황조회**

아래 링크에서 PG사별로 심사 진행현황을 조회해보실 수 있습니다.  계약이 지연되거나 심사가 너무 오래 진행된다고 판단되시는 경우 포트원으로 문의주시면 확인 도와드리겠습니다.

<Callout content="결제대행사에서 제공하는 심사 진행현황은 실시간 반영은 아니므로 정확한 사항은 심사 진행중이신 결제대행사로 확인해주시기 바랍니다." title="참고사항" icon="💡" />

- [KG이니시스 카드사 심사현황 바로가기↗︎](https://www.inicis.com/check_card)
- [NHN KCP 카드사 심사현황 바로가기↗︎](https://www.kcp.co.kr/viewApplicationParent/viewApplication/00)
- [나이스페이먼츠 카드사 심사현황 바로가기↗︎](https://www.nicepay.co.kr/apply/progress/card.do)
- [다날 계약현황 바로가기↗︎](https://contract.danalpay.com/std/search)
- [KICC(한국정보통신) 계약현황 바로가기↗︎](https://www.easypay.co.kr/application/ApplyProgressAction.do)
- [헥토파이낸셜 심사현황 바로가기↗︎](https://pg.sbsvc.online/pgmemsvc/MemberMultiAction.do?_method=serviceReqState)
- [키움페이 카드사 심사현황 바로가기↗︎](https://pg.kiwoompay.co.kr/main/status)
